greenheart.simulation.technologies.offshore.all\_platforms
==========================================================

.. automodule:: greenheart.simulation.technologies.offshore.all_platforms

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      calc_platform_opex
      install_platform
   
   

   
   
   

   
   
   



